import type { HighlighterCore, HighlighterCoreOptions } from "shiki/core";
/**
 * Lazy-load shiki instance.
 *
 * You can use this utility both in `server/` and vue app code.
 *
 * @example
 *
 * ```vue
 * <script setup>
 *   const shiki = await loadShiki();
 *   const html = shiki.codeToHtml('const hello = "shiki";', { ...$shit.$defaults, lang: 'javascript' });
 * </script>
 * ```
 *
 * @example
 *
 * ```ts
 * // server/api/highlight.ts
 * import { loadShiki, getQuery } from "#imports";
 *
 * export default defineEventHandler(async (event) => {
 *   const shiki = await loadShiki();
 *   const { code } = getQuery(event);
 *   return shiki.codeToHtml(code, { ...$shit.$defaults });
 * });
 * ```
 */
export declare function loadShiki(): Promise<HighlighterCore & {
    $config: HighlighterCoreOptions & {
        defaultTheme: string;
        defaultLang: string;
    };
    $defaults: {
        lang: string;
        theme: string;
    };
}>;
